==> adfurikun-1.0.1.tar.gz: example/lib/reward_sample.dart <==
import 'dart:io';

import 'package:adfurikun/reward.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';

class RewardPage extends StatefulWidget {
  RewardPage({Key? key}) : super(key: key);
  @override
  RewardPageState createState() => RewardPageState();
}

class RewardPageState extends State<RewardPage> with WidgetsBindingObserver {

  String messageLog = "";
  late AdfurikunReward reward;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Reward Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: Text(messageLog)
            ),
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_REWARD_APPID;
    } else {
      appId = IOS_REWARD_APPID;
    }
    reward = AdfurikunReward(appId);
    reward.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
    reward.destroy();
    reward.listener = null;
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (AppLifecycleState.resumed == state) {
      reward.resume();
    } else if (AppLifecycleState.paused == state) {
      reward.pause();
    }
  }

  void load() {
    setState(() {
      messageLog = "動画広告の準備を開始します。" + "\n" + messageLog;
    });
    reward.load();
  }

  void show() async {
    bool isPrepared = await reward.isPrepared();
    if (isPrepared) {
      reward.play();
    }
  }

  void notifyCallback(AdfurikunRewardCallback? callback, String? appId, String? adNetworkKey, int? errorCode) {
    setState(() {
      String message = "";
      if (AdfurikunRewardCallback.onPrepareSuccess == callback) {
        message = "動画広告の準備が完了しました。\n";
      } else if (AdfurikunRewardCallback.onPrepareFailure == callback) {
        message = "動画広告の準備が失敗しました。($errorCode)\n";
      } else if (AdfurikunRewardCallback.onStartPlaying == callback) {
        message = "動画広告の再生を開始しました。($adNetworkKey)\n";
      } else if (AdfurikunRewardCallback.onFinishedPlaying == callback) {
        message = "動画広告の再生が完了しました。($adNetworkKey)\n";
      } else if (AdfurikunRewardCallback.onFailedPlaying == callback) {
        message = "動画広告の再生が中断しました。($adNetworkKey)\n";
      } else if (AdfurikunRewardCallback.onAdClose == callback) {
        message = "動画広告を閉じました。($adNetworkKey)\n";
      }
      messageLog = message + messageLog;
    });
  }
}

==> adfurikun-1.5.0.tar.gz: example/lib/reward_sample.dart <==
import 'dart:io';

import 'package:adfurikun/reward.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';

class RewardPage extends StatefulWidget {
  RewardPage({Key? key}) : super(key: key);
  @override
  RewardPageState createState() => RewardPageState();
}

class RewardPageState extends State<RewardPage> {

  String messageLog = "";
  late AdfurikunReward reward;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Reward Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: Text(messageLog)
            ),
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_REWARD_APPID;
    } else {
      appId = IOS_REWARD_APPID;
    }
    reward = AdfurikunReward(appId);
    reward.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    reward.destroy();
    reward.listener = null;
  }

  void load() {
    setState(() {
      messageLog = "動画広告の準備を開始します。" + "\n" + messageLog;
    });
    reward.load();
  }

  void show() async {
    bool isPrepared = await reward.isPrepared();
    if (isPrepared) {
      reward.play();
    }
  }

  void notifyCallback(AdfurikunRewardCallback? callback, String? appId, String? adNetworkKey, int? errorCode) {
    setState(() {
      String message = "";
      if (AdfurikunRewardCallback.onPrepareSuccess == callback) {
        message = "動画広告の準備が完了しました。\n";
      } else if (AdfurikunRewardCallback.onPrepareFailure == callback) {
        message = "動画広告の準備が失敗しました。($errorCode)\n";
      } else if (AdfurikunRewardCallback.onStartPlaying == callback) {
        message = "動画広告の再生を開始しました。($adNetworkKey)\n";
      } else if (AdfurikunRewardCallback.onFinishedPlaying == callback) {
        message = "動画広告の再生が完了しました。($adNetworkKey)\n";
      } else if (AdfurikunRewardCallback.onFailedPlaying == callback) {
        message = "動画広告の再生が中断しました。($adNetworkKey)\n";
      } else if (AdfurikunRewardCallback.onAdClose == callback) {
        message = "動画広告を閉じました。($adNetworkKey)\n";
      }
      messageLog = message + messageLog;
    });
  }
}
